;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "2.1.0.20200204.173031" "Map manipulation functions" '((emacs "25")) :url "https://elpa.gnu.org/packages/map.html" :keywords '("convenience" "map" "hash-table" "alist" "array") :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org"))
